/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::Network
 * Copyright (c) 2004-2013 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    HTTP_Server.c
 * Purpose: HTTP Server example
 *----------------------------------------------------------------------------*/

#include <stdio.h>
#include <string.h>
#include "cmsis_os.h"                   /* CMSIS RTOS definitions             */
#include "rl_net.h"                     /* Network definitions                */
#include "rl_net_lib.h"                 /* Network library definitions        */

#include "GLCD.h"
#include "LED.h"
#include "Keyboard.h"
#include "ADC.h"

bool LEDrun;
bool LCDupdate;
char lcd_text[2][16+1] = { " ", "Waiting for DHCP" };

extern LOCALM localm[];
#define MY_IP localm[NETIF_ETH].IpAdr

static void BlinkLed (void const *arg);
static void Display (void const *arg);

osThreadDef(BlinkLed, osPriorityNormal, 1, 0);
osThreadDef(Display, osPriorityNormal, 1, 0);

/// Read analog inputs
uint16_t AD_in (uint32_t ch) {
  ADC_StartConversion();
  return (ADC_GetValue());
}

/// Read digital inputs
uint8_t get_button (void) {
  return (Keyboard_GetKeys ());
}

/// Check DHCP if IP address assigned
static void dhcp_check (void) {
  static uint8_t ip[IP_ADDR_LEN];

  if (!memcmp (&MY_IP, ip, IP_ADDR_LEN)) {
    return;
  }
  // IP address has changed
  memcpy (ip, &MY_IP, IP_ADDR_LEN);
  sprintf((char *)lcd_text[0],"IP address:");
  sprintf((char *)lcd_text[1],"%d.%d.%d.%d", ip[0], ip[1], ip[2], ip[3]);
  LCDupdate = true;
}

/*----------------------------------------------------------------------------
  Thread 'Display': LCD display handler
 *---------------------------------------------------------------------------*/
static void Display (void const *arg) {

  GLCD_Initialize ();
  GLCD_Clear (Blue);
  GLCD_SetBackColor (Blue);
  GLCD_SetTextColor (White);

  GLCD_DisplayString (1, 4, 1, "   MDK-MW");
  GLCD_DisplayString (2, 4, 1, "HTTP example");
  LCDupdate = true;

  while(1) {
    if (LCDupdate == true) {
      GLCD_ClearLn (5, 1 );
      GLCD_DisplayString (5, 0, 1, lcd_text[0]);
      GLCD_ClearLn (6, 1);
      GLCD_DisplayString (6, 0, 1, lcd_text[1]);
      LCDupdate = false;
    }
    osDelay (250);
  }
}

/*----------------------------------------------------------------------------
  Thread 'BlinkLed': Blink the LEDs on an eval board
 *---------------------------------------------------------------------------*/
static void BlinkLed (void const *arg) {
  const uint8_t led_val[16] = { 0x48,0x88,0x84,0x44,0x42,0x22,0x21,0x11,
                                0x12,0x0A,0x0C,0x14,0x18,0x28,0x30,0x50 };
  int cnt = 0;

  LEDrun = true;
  while(1) {
    // Every 100 ms
    if (LEDrun == true) {
      LED_Out (led_val[cnt]);
      if (++cnt >= sizeof(led_val)) {
        cnt = 0;
      }
    }
    osDelay (100);
  }
}

/*----------------------------------------------------------------------------
  Main Thread 'main': Run Network
 *---------------------------------------------------------------------------*/
int main (void) {
  LED_Initialize ();
  Keyboard_Initialize ();
  ADC_Initialize ();
  net_initialize ();

  osThreadCreate (osThread(BlinkLed), NULL);
  osThreadCreate (osThread(Display), NULL);

  while(1) {
    net_main ();
    dhcp_check ();
    osThreadYield ();
  }
}
