/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::Network
 * Copyright (c) 2004-2013 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    SNMP_Agent.c
 * Purpose: SNMP Agent example
 *----------------------------------------------------------------------------*/

#include <stdio.h>
#include <string.h>
#include "cmsis_os.h"                   /* CMSIS RTOS definitions            */
#include "rl_net.h"                     /* Network definitions               */
#include "rl_net_lib.h"                 /* Network library definitions       */

#include "GLCD.h"
#include "LED.h"
#include "Keyboard.h"
#include "ADC.h"

bool LCDupdate;
char lcd_text[2][16+1] = { " ", "Waiting for DHCP" };

extern LOCALM localm[];
#define MY_IP localm[NETIF_ETH].IpAdr

static void Display (void const *arg);

osThreadDef(Display, osPriorityNormal, 1, 0);

/// Read digital inputs
uint8_t get_button (void) {
  return (Keyboard_GetKeys ());
}

/// Check DHCP if IP address assigned
static void dhcp_check (void) {
  static uint8_t ip[IP_ADDR_LEN];

  if (!memcmp (&MY_IP, ip, IP_ADDR_LEN)) {
    return;
  }
  // IP address has changed
  memcpy (ip, &MY_IP, IP_ADDR_LEN);
  sprintf((char *)lcd_text[0],"IP address:");
  sprintf((char *)lcd_text[1],"%d.%d.%d.%d", ip[0], ip[1], ip[2], ip[3]);
  LCDupdate = true;
}

/*----------------------------------------------------------------------------
  Thread 'Display': LCD display handler
 *---------------------------------------------------------------------------*/
static void Display (void const *arg) {

  GLCD_Initialize ();
  GLCD_Clear (Blue);
  GLCD_SetBackColor (Blue);
  GLCD_SetTextColor (White);

  GLCD_DisplayString (1, 4, 1, "   MDK-MW");
  GLCD_DisplayString (2, 4, 1, "SNMP example");
  LCDupdate = true;

  while(1) {
    if (LCDupdate == true) {
      GLCD_ClearLn (5, 1 );
      GLCD_DisplayString (5, 0, 1, lcd_text[0]);
      GLCD_ClearLn (6, 1);
      GLCD_DisplayString (6, 0, 1, lcd_text[1]);
      LCDupdate = false;
    }
    osDelay (250);
  }
}

/*----------------------------------------------------------------------------
  Main Thread 'main': Run Network
 *---------------------------------------------------------------------------*/
int main (void) {
  LED_Initialize ();
  Keyboard_Initialize ();
  net_initialize ();

  osThreadCreate (osThread(Display), NULL);

  while (1) {
    net_main ();
    dhcp_check ();
    osThreadYield ();
  }
}
